@@ -11,12 +11,14 @@ typedef enum {
   JSON_DEBUG_PATH    = 1 << 2
 } JsonDebugFlags;
 
+#define JSON_HAS_DEBUG(flag)    (json_get_debug_flags () & JSON_DEBUG_##flag)
+
 #ifdef JSON_ENABLE_DEBUG
 
 # ifdef __GNUC__
 
 # define JSON_NOTE(type,x,a...)                 G_STMT_START {  \
-        if (_json_get_debug_flags () & JSON_DEBUG_##type) {     \
+        if (JSON_HAS_DEBUG (type)) {                            \
           g_message ("[" #type "] " G_STRLOC ": " x, ##a);      \
         }                                       } G_STMT_END
 
@@ -26,7 +28,7 @@ typedef enum {
  * do an intemediate printf.
  */
 # define JSON_NOTE(type,...)                    G_STMT_START {  \
-        if (_json_get_debug_flags () & JSON_DEBUG_##type) {     \
+        if (JSON_HAS_DEBUG (type)) {                            \
             gchar * _fmt = g_strdup_printf (__VA_ARGS__);       \
             g_message ("[" #type "] " G_STRLOC ": %s",_fmt);    \
             g_free (_fmt);                                      \
@@ -40,7 +42,8 @@ typedef enum {
 
 #endif /* JSON_ENABLE_DEBUG */
 
-JsonDebugFlags _json_get_debug_flags (void);
+G_GNUC_INTERNAL
+JsonDebugFlags json_get_debug_flags (void);
 
 G_END_DECLS
 
