@@ -30,9 +30,7 @@
  * inside a file or inside a static buffer.
  */
 
-#ifdef HAVE_CONFIG_H
 #include "config.h"
-#endif
 
 #include <string.h>
 
